@@ -6,13 +6,18 @@ use List::Util qw( shuffle );
 use Carp;
 
 our @ISA = qw( Acme::MetaSyntactic::RemoteList );
+our $VERSION = '1.000';
 
 sub init {
+    my ($self, $data) = @_;
     my $class = caller(0);
-    my $data  = Acme::MetaSyntactic->load_data($class);
+
+    $data ||= Acme::MetaSyntactic->load_data($class);
     no strict 'refs';
 
-    my $sep = ${"$class\::Separator"} ||= '/';
+    # note: variables mentioned twice to avoid a warning
+
+    my $sep = ${"$class\::Separator"} = ${"$class\::Separator"} ||= '/';
     my $tail = qr/$sep?[^$sep]*$/;
 
     # compute all categories
@@ -31,8 +36,8 @@ sub init {
         }
     }
 
-    ${"$class\::Default"} = $data->{default} || ':all';
-    ${"$class\::Theme"} = ( split /::/, $class )[-1];
+    ${"$class\::Default"} = ${"$class\::Default"} = $data->{default} || ':all';
+    ${"$class\::Theme"} = ${"$class\::Theme"} = ( split /::/, $class )[-1];
 
     *{"$class\::import"} = sub {
         my $callpkg = caller(0);
@@ -41,7 +46,7 @@ sub init {
         *{"$callpkg\::meta$theme"} = sub { $meta->name(@_) };
     };
 
-    ${"$class\::meta"} = $class->new();
+    ${"$class\::meta"} = ${"$class\::meta"} = $class->new();
 }
 
 sub name {
